pub struct Error(/* private fields */);Expand description
Nostr database error.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn new<E>(kind: ErrorKind, error: E) -> Self
pub fn new<E>(kind: ErrorKind, error: E) -> Self
Creates a new error from a kind and an arbitrary error payload.
The payload is preserved as the error source, and its display output is captured as the error message.
Sourcepub const fn simple(kind: ErrorKind) -> Self
pub const fn simple(kind: ErrorKind) -> Self
Creates an error without a specific message or source.
Sourcepub const fn with_static_message(kind: ErrorKind, message: &'static str) -> Self
pub const fn with_static_message(kind: ErrorKind, message: &'static str) -> Self
Creates an error with a static message.