pub struct Features {
pub persistent: bool,
pub event_expiration: bool,
pub full_text_search: bool,
pub request_to_vanish: bool,
}Expand description
Backend features
Fields
persistent: boolWhether the database supports persistent storage.
event_expiration: boolWhether the database supports event expiration (NIP-40)
When supported, the database will automatically exclude expired events from query results and/or delete them.
full_text_search: boolWhether the database supports full-text search (NIP-50)
request_to_vanish: boolWhether the database supports the request to vanish (NIP-62)